@@ -52,6 +52,8 @@ LOGIC_PREFIX = b"Program"
 """bytes: program (logic) prefix when signing"""
 LOGIC_DATA_PREFIX = b"ProgData"
 """bytes: program (logic) data prefix when signing"""
+APPID_PREFIX = b"appID"
+"""bytes: application ID prefix when signing"""
 
 
 HASH_LEN = 32
@@ -87,18 +89,21 @@ LOGIC_SIG_MAX_COST = 20000
 LOGIC_SIG_MAX_SIZE = 1000
 """int: max size of a teal program and its arguments in bytes"""
 
-#for backward compatibility:
-kmd_auth_header = KMD_AUTH_HEADER 
-algod_auth_header = ALGOD_AUTH_HEADER 
-indexer_auth_header = INDEXER_AUTH_HEADER 
-unversioned_paths = UNVERSIONED_PATHS 
-no_auth = NO_AUTH 
-payment_txn = PAYMENT_TXN 
-keyreg_txn = KEYREG_TXN 
-assetconfig_txn = ASSETCONFIG_TXN 
-assetfreeze_txn = ASSETFREEZE_TXN 
-assettransfer_txn = ASSETTRANSFER_TXN 
-appcall_txn = APPCALL_TXN 
+ZERO_ADDRESS = "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAY5HFKQ"
+"""str: algorand encoded address of 32 zero bytes"""
+
+# for backward compatibility:
+kmd_auth_header = KMD_AUTH_HEADER
+algod_auth_header = ALGOD_AUTH_HEADER
+indexer_auth_header = INDEXER_AUTH_HEADER
+unversioned_paths = UNVERSIONED_PATHS
+no_auth = NO_AUTH
+payment_txn = PAYMENT_TXN
+keyreg_txn = KEYREG_TXN
+assetconfig_txn = ASSETCONFIG_TXN
+assetfreeze_txn = ASSETFREEZE_TXN
+assettransfer_txn = ASSETTRANSFER_TXN
+appcall_txn = APPCALL_TXN
 note_field_type_deposit = NOTE_FIELD_TYPE_DEPOSIT
 note_field_type_bid = NOTE_FIELD_TYPE_BID
 note_field_type_settlement = NOTE_FIELD_TYPE_SETTLEMENT
